.. -*- mode: rst ; ispell-local-dictionary: "american" -*-

.. include:: _manpage-header.rst

==========================
git flow support
==========================
.. |BRANCH| replace:: support
.. |`BRANCH`| replace:: `support`
.. |BASE| replace:: `master`


Manage your |BRANCH| branches
#################################

Synopsis
+++++++++++++++

.. parsed-literal::

  `git flow` |`BRANCH`| [-h|--help]
  `git flow` |`BRANCH`| `list` [-v|--verbose]
  `git flow` |`BRANCH`| `start` [-F|--fetch] name [base]


.. contents:: Subcommands
    :depth: 1
    :local:

.. include:: _subcmd-list.rst
.. include:: _subcmd-start.rst


.. include:: _manpage-footer.rst
